@@ -121,8 +121,10 @@ class Provider(AddressProvider):
         return self.numerify(
             self.random_element(self.secondary_address_formats))
 
-    def state(self):
+    def administrative_unit(self):
         return self.random_element(self.states)
 
+    state = administrative_unit
+
     def state_abbr(self):
         return self.random_element(self.states_abbr)
