@@ -19,7 +19,7 @@ class Provider(BankProvider):
         '42', '44', '45', '46', '47', '49', '50', '52', '53', '54', '56', '57', '58', '60', '61', '63',
         '64', '65', '66', '67', '68', '69', '70', '71', '73', '75', '76', '77', '78', '79', '80', '81',
         '82', '83', '84', '85', '86', '87', '88', '89', '90', '91', '92', '93', '94', '95', '96', '97',
-        '98', '99', '111', '118', '7110', '718', '7114', '719',
+        '98', '99',
     )
 
     department_code_formats = (
